﻿////------------------------------------------------------------------------------------------
//
//    MindFusion Office Floorplan Designer 
//     Copyright (c) 2022, MindFusion LLC - Bulgaria
//
////------------------------------------------------------------------------------------------

using System.Drawing;


namespace FloorplanDesigner
{
   /// <summary>
   /// This class implements a floorplan item of type "Internal Wall", and is derived from 
   /// NodeWallBase.
   /// 
   /// This class contains no functionality. The only difference between an external and internal 
   /// wall node is the color and width.
   /// </summary>
   public class NodeWallInternal : NodeWallBase
   {
      // Paramerterless constructor, needed for deserialization and copy from clipboard
      public NodeWallInternal()
         : this(PointF.Empty, 0, false)
      {}


      // Constructor for when user creates an item on the diagram area
      public NodeWallInternal(PointF startPoint)
         : this(startPoint, 0, false)
      {}


      // Constructor used by above constructors, and also used to create a wall via programming
      public NodeWallInternal(PointF startPoint, int initialWallLength, bool isVertical)
          : base(Color.FromArgb(0, 52, 102), 7f, startPoint, initialWallLength, isVertical)
      {}


      // Copy constructor, needed for copy to/from clipboard
      public NodeWallInternal(NodeWallInternal copyFrom)
         : base(copyFrom)
      {}


      // Properties required by the NodeItemBase class. This node can only be "drawn", not "dropped" 
      //  on the floorplan.

      public override bool IsDrawable
      { get { return true; }}

      public override bool IsDroppable
      { get { return false; }}
   }
}
